@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2014 by Hong Minhee <http://hongminhee.org/>
+# Copyright (C) 2011-2020 by Hong Minhee <https://hongminhee.org/>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -21,7 +21,7 @@
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 This module provides a simple WSGI middleware that requires the user to
-authenticate via the specific `OAuth 2.0`_ service e.g. Facebook_, Google_.
+authenticate via the specific `OAuth 2.0`_ service, e.g., Facebook_, Google_.
 
 .. _OAuth 2.0: http://oauth.net/2/
 .. _Facebook: http://www.facebook.com/
@@ -30,7 +30,10 @@ authenticate via the specific `OAuth 2.0`_ service e.g. Facebook_, Google_.
 """
 import base64
 import binascii
-import cgi
+try:
+    from html import escape as html_escape
+except ImportError:
+    from cgi import escape as html_escape
 try:
     import Cookie
 except ImportError:
@@ -60,10 +63,10 @@ else:
     from urllib import urlencode
 
 __author__ = 'Hong Minhee'  # http://hongminhee.org/
-__email__ = 'minhee' "@" 'dahlia.kr'
+__email__ = 'hong.minhee' "@" 'gmail.com'
 __license__ = 'MIT License'
-__version__ = '0.2.0'
-__copyright__ = '2011-2014, Hong Minhee'
+__version__ = '0.2.2'
+__copyright__ = '2011-2020, Hong Minhee'
 
 __all__ = ('AccessToken', 'Client', 'GitHubService', 'GithubService',
            'Service', 'WSGIMiddleware', 'github', 'google', 'facebook')
@@ -190,7 +193,7 @@ class GitHubService(Service):
         response = json.loads(response)
         # Copy useful data
         access_token["username"] = response["login"]
-        access_token["name"] = response["name"]
+        access_token["name"] = response.get("name", "")
 
     def is_user_allowed(self, access_token):
         """Check if the authenticated user is allowed to access the protected
@@ -372,7 +375,7 @@ class AccessToken(dict):
         :type headers: :class:`collections.Mapping`
 
         """
-        url += '&' if '?' in url else '?' + 'access_token=' + self.access_token
+        url += ('&' if '?' in url else '?') + 'access_token=' + self.access_token
         request = urllib2.Request(url, headers=headers)
         return urllib2.urlopen(request)
 
@@ -551,7 +554,7 @@ class WSGIMiddleware(object):
         h = {'Content-Type': 'text/html; charset=utf-8', 'Location': url}
         h.update(headers)
         start_response('307 Temporary Redirect', list(h.items()))
-        e_url = cgi.escape(url).encode('iso-8859-1')
+        e_url = html_escape(url).encode('iso-8859-1')
         yield b'<!DOCTYPE html>'
         yield b'<html><head><meta charset="utf-8">'
         yield b'<meta http-equiv="refresh" content="0; url='
